@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 2002-2015 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Base class for all web GUI components."""
 
@@ -62,6 +63,7 @@ class GUIBase:
             if isinstance(val, ListType):
                 return val
             addrs = []
+            bad_addrs = []
             for addr in [s.strip() for s in val.split(NL)]:
                 # Discard empty lines
                 if not addr:
@@ -76,16 +78,36 @@ class GUIBase:
                         try:
                             re.compile(addr)
                         except re.error:
-                            raise ValueError
+                            bad_addrs.append(addr)
+                    elif (wtype == mm_cfg.EmailListEx and addr.startswith('@')
+                            and (property.endswith('_these_nonmembers') or
+                                property == 'subscribe_auto_approval')):
+                        # XXX Needs to be reviewed for list@domain names.
+                        # don't reference your own list
+                        if addr[1:] == mlist.internal_name():
+                            bad_addrs.append(addr)
+                        # check for existence of list?  For now allow
+                        # reference to list before creating it.
                     else:
-                        raise
+                        bad_addrs.append(addr)
+                if property in ('regular_exclude_lists',
+                                'regular_include_lists'):
+                    if addr.lower() == mlist.GetListEmail().lower():
+                        bad_addrs.append(addr)
                 addrs.append(addr)
+            if bad_addrs:
+                raise Errors.EmailAddressError, ', '.join(bad_addrs)
             return addrs
         # This is a host name, i.e. verbatim
         if wtype == mm_cfg.Host:
             return val
         # This is a number, either a float or an integer
         if wtype == mm_cfg.Number:
+            # The int/float code below doesn't work if we are called from
+            # config_list with a value that is already a float.  It will
+            # truncate the value to an int.
+            if isinstance(val, float):
+                return val
             num = -1
             try:
                 num = int(val)
@@ -122,10 +144,6 @@ class GUIBase:
         # Validate all the attributes for this category
         pass
 
-    def _escape(self, property, value):
-        value = value.replace('<', '&lt;')
-        return value
-
     def handleForm(self, mlist, category, subcat, cgidata, doc):
         for item in self.GetConfigInfo(mlist, category, subcat):
             # Skip descriptions and legacy non-attributes
@@ -144,10 +162,9 @@ class GUIBase:
             elif not cgidata.has_key(property):
                 continue
             elif isinstance(cgidata[property], ListType):
-                val = [self._escape(property, x.value)
-                       for x in cgidata[property]]
+                val = [x.value for x in cgidata[property]]
             else:
-                val = self._escape(property, cgidata[property].value)
+                val = cgidata[property].value
             # Coerce the value to the expected type, raising exceptions if the
             # value is invalid.
             try:
@@ -155,9 +172,9 @@ class GUIBase:
             except ValueError:
                 doc.addError(_('Invalid value for variable: %(property)s'))
             # This is the parent of MMBadEmailError and MMHostileAddress
-            except Errors.EmailAddressError:
+            except Errors.EmailAddressError, error:
                 doc.addError(
-                    _('Bad email address for option %(property)s: %(val)s'))
+                    _('Bad email address for option %(property)s: %(error)s'))
             else:
                 # Set the attribute, which will normally delegate to the mlist
                 self._setValue(mlist, property, val, doc)
