@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.7
 
 from __future__ import nested_scopes
 
@@ -16,6 +16,7 @@ __version__ = '0.09 (Mailman edition)'
 VERSION = __version__
 CACHESIZE = 100    # Number of slots in the cache
 
+from Mailman import mm_cfg
 from Mailman import Errors
 from Mailman.Mailbox import ArchiverMailbox
 from Mailman.Logging.Syslog import syslog
@@ -122,9 +123,10 @@ class Database(DatabaseInterface):
         parentID = article.parentID
         if parentID is not None and self.articleIndex.has_key(parentID):
             parent = self.getArticle(archive, parentID)
-            myThreadKey = parent.threadKey + article.date + '-'
+            myThreadKey = (parent.threadKey + article.date + '.'
+                           + str(article.sequence) + '-')
         else:
-            myThreadKey = article.date + '-'
+            myThreadKey = article.date + '.' + str(article.sequence) + '-'
         article.threadKey = myThreadKey
         key = myThreadKey, article.msgid
         self.setThreadKey(archive, key, article.msgid)
@@ -229,21 +231,30 @@ class Article:
         self.body = s.readlines()
 
     def _set_date(self, message):
-        def floatdate(header):
-            missing = []
-            datestr = message.get(header, missing)
-            if datestr is missing:
+        def floatdate(datestr):
+            if not datestr:
                 return None
             date = parsedate_tz(datestr)
             try:
-                return mktime_tz(date)
+                date = mktime_tz(date)
+                if (date < 0 or
+                    date - time.time() >
+                        mm_cfg.ARCHIVER_ALLOWABLE_SANE_DATE_SKEW
+                   ):
+                    return None
+                return date
             except (TypeError, ValueError, OverflowError):
                 return None
-        date = floatdate('date')
+        date = floatdate(message.get('date'))
         if date is None:
-            date = floatdate('x-list-received-date')
+            date = floatdate(message.get('x-list-received-date'))
+        if date is None:
+            date = floatdate(re.sub(r'^.*;\s*', '',
+                                    message.get('received', ''), flags=re.S))
+        if date is None:
+            date = floatdate(re.sub(r'From \s*\S+\s+', '',
+                                    message.get_unixfrom() or '' ))
         if date is None:
-            # What's left to try?
             date = self._last_article_time + 1
         self._last_article_time = date
         self.date = '%011i' % date
@@ -418,7 +429,8 @@ class T:
                 else:
                     parent = self.database.getArticle(self.archive,
                                                     article.parentID)
-                    article.threadKey = parent.threadKey+article.date+'-'
+                    article.threadKey = (parent.threadKey + article.date + '.'
+                                         + str(article.sequence) + '-')
                 self.database.setThreadKey(self.archive,
                     (article.threadKey, article.msgid),
                     msgid)
@@ -550,6 +562,8 @@ class T:
         if start is None:
             start = 0
         counter = 0
+        if start:
+            mbox.skipping(True)
         while counter < start:
             try:
                 m = mbox.next()
@@ -558,6 +572,8 @@ class T:
             if m is None:
                 return
             counter += 1
+        if start:
+            mbox.skipping(False)
         while 1:
             try:
                 pos = input.tell()
@@ -632,9 +648,11 @@ class T:
             article.parentID = parentID = self.get_parent_info(arch, article)
             if parentID:
                 parent = self.database.getArticle(arch, parentID)
-                article.threadKey = parent.threadKey + article.date + '-'
+                article.threadKey = (parent.threadKey + article.date + '.'
+                                     + str(article.sequence) + '-')
             else:
-                article.threadKey = article.date + '-'
+                article.threadKey = (article.date + '.'
+                                     + str(article.sequence) + '-')
             key = article.threadKey, article.msgid
 
             self.database.setThreadKey(arch, key, article.msgid)
@@ -647,8 +665,10 @@ class T:
     def get_parent_info(self, archive, article):
         parentID = None
         if article.in_reply_to:
-            parentID = article.in_reply_to
-        elif article.references:
+            if self.database.hasArticle(archive, article.in_reply_to):
+                # Only use In-Reply-To if it's in the archive.
+                parentID = article.in_reply_to
+        if not parentID and article.references:
             refs = self._remove_external_references(article.references)
             if refs:
                 maxdate = self.database.getArticle(archive, refs[0])
@@ -657,11 +677,15 @@ class T:
                     if a.date > maxdate.date:
                         maxdate = a
                 parentID = maxdate.msgid
-        else:
+        if not parentID:
             # Get the oldest article with a matching subject, and
             # assume this is a follow-up to that article
-            parentID = self.database.getOldestArticle(archive,
-                                                      article.subject)
+            # But, use the subject that's in the database
+            if article.decoded.has_key('stripped'):
+                subject = article.decoded['stripped'].lower()
+            else:
+                subject = article.subject.lower()
+            parentID = self.database.getOldestArticle(archive, subject)
 
         if parentID and not self.database.hasArticle(archive, parentID):
             parentID = None
